#ifndef EXIST_FILE_H
#define EXIST_FILE_H

/*!
  \file
  \brief t@CL̊mF

  access() ̃bp[

  \author Satofumi KAMIMURA

  \todo SearchFilePath Å֐Ă΂悤ɂ
  \todo SearchFilePath Ńt@CL𒲂ׂĂӏu
*/

namespace beego {
  extern bool existFile(const char* file_path);
};

#endif /* !EXIST_FILE_H */
